seqtools.partition_sequence_once_by_counts_without_overhang
===========================================================

.. autofunction:: abjad.tools.seqtools.partition_sequence_once_by_counts_without_overhang
